swutil
==========================================
:Author: Soeren Wolfers <soeren.wolfers@gmail.com>
:Organization: King Abdullah University of Science and Technology (KAUST) 

This package provides common tools for logging, plotting, configuration, etc., 
that are commonly used by the author in other projects.

---

To install run :code:`pip install swutil`

---

For usage instructions check the `documentation </doc/_build/index.html>_`

